@@ -1,7 +1,7 @@
 package Inline::Filters;
 use strict;
 use Config;
-our $VERSION = "0.17";
+our $VERSION = "0.18";
 use File::Spec;
  
 #============================================================================
@@ -129,7 +129,7 @@ sub Preprocess {
     open $CSRC, ">", $tmpfile or die $!;
     print $CSRC $code;
     close $CSRC;
-    open $PROCESSED, "$cpp $tmpfile |" or die $!;
+    open $PROCESSED, "$cpp \"$tmpfile\" |" or die $!;
     $code = join '', <$PROCESSED>;
     close $PROCESSED;
     unlink $tmpfile;
